@@ -1,4 +1,4 @@
 # VERSION 0.2.2
 from .utils import MyTimer, MyFpsCounter, try_import, mfc
-from .cv_ops import CVImage, CVQueue, CVFile, CVVideo, CVVideoLoader, CVVideoMaker, CVExcel
+from .cv_ops import CVImage, CVQueue, CVFile, CVVideo, CVVideoLoader, CVVideoMaker, CVExcel, CVFolder
 from .code_templates import Factory, Consumer
